@@ -23,7 +23,7 @@ from aliyunsdkcloudauth.endpoint import endpoint_data
 class ModifyDeviceInfoRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'ModifyDeviceInfo')
+		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'ModifyDeviceInfo','cloudauth')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
@@ -48,18 +48,6 @@ class ModifyDeviceInfoRequest(RpcRequest):
 	def set_ExpiredDay(self,ExpiredDay):
 		self.add_query_param('ExpiredDay',ExpiredDay)
 
-	def get_SourceIp(self):
-		return self.get_query_params().get('SourceIp')
-
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_Lang(self):
-		return self.get_query_params().get('Lang')
-
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
 	def get_DeviceId(self):
 		return self.get_query_params().get('DeviceId')
 
